@@ -38,11 +38,11 @@ RDF::LinkedData - A simple Linked Data implementation
 
 =head1 VERSION
 
-Version 0.57_02
+Version 0.57_03
 
 =cut
 
-our $VERSION = '0.57_02';
+our $VERSION = '0.57_03';
 
 
 =head1 SYNOPSIS
@@ -355,19 +355,21 @@ sub response {
 sub merge {
 	my $self = shift;
 	my $uri = URI->new(shift);
-#	my $payloadmodel = RDF::Trine::Model->temporary_model;
-	my $payload = $self->request->content;
-	my $headers_in = $self->request->headers;
 	my $response = Plack::Response->new;
-	eval {
-		my $parser = RDF::Trine::Parser->parser_by_media_type($headers_in->content_type);
-		$parser->parse_into_model($self->base_uri, $payload, $self->model);
-	};
-	if ($@) {
-		$response->status(400);
-		$response->content_type('text/plain');
-		$response->body("Couldn't parse the payload: $@");
-		return $response;
+	my $payload = $self->request->content;
+	if ($payload) {
+	  my $headers_in = $self->request->headers;
+	  $self->logger->debug('Will merge payload as ' . $headers_in->content_type);
+	  eval {
+		 my $parser = RDF::Trine::Parser->parser_by_media_type($headers_in->content_type);
+		 $parser->parse_into_model($self->base_uri, $payload, $self->model);
+	  };
+	  if ($@) {
+		 $response->status(400);
+		 $response->content_type('text/plain');
+		 $response->body("Couldn't parse the payload: $@");
+		 return $response;
+	  }
 	}
 	$response->status(204);
 	return $response;
